@@ -5,7 +5,6 @@ See [`execute-command-macro`](https://crates.io/crates/execute-command-macro).
 */
 
 extern crate execute_command_tokens;
-extern crate proc_macro_hack;
 
 #[macro_use]
 extern crate syn;
@@ -16,12 +15,20 @@ extern crate quote;
 extern crate proc_macro;
 
 use proc_macro::TokenStream;
-use proc_macro_hack::proc_macro_hack;
 use syn::LitStr;
 
 use execute_command_tokens::command_tokens;
 
-#[proc_macro_hack]
+/**
+Generate the statements at compile time to create a `Command` instance by a command string.
+
+```rust
+#[macro_use] extern crate execute_command_macro_impl;
+
+let command = command!("program arg1 arg2 -opt1 -opt2");
+```
+*/
+#[proc_macro]
 pub fn command(input: TokenStream) -> TokenStream {
     let s = parse_macro_input!(input as LitStr).value();
 
